==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/BouncesRemoveListResult.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.BouncesRemoveListError;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * BouncesRemoveListResult
 */
@JsonPropertyOrder({ BouncesRemoveListResult.JSON_PROPERTY_ERRORS })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class BouncesRemoveListResult implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ERRORS = "errors";
    private List<BouncesRemoveListError> errors = null;

    public BouncesRemoveListResult() {
    }

    public BouncesRemoveListResult errors(List<BouncesRemoveListError> errors) {

        this.errors = errors;
        return this;
    }

    public BouncesRemoveListResult adderrorsItem(BouncesRemoveListError errorsItem) {
        if (this.errors == null) {
            this.errors = new ArrayList<>();
        }
        this.errors.add(errorsItem);
        return this;
    }

    /**
     * A list of emails that wasn&#39;t added to the email-bounced remove list and the error reason
     *
     * @return errors
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "A list of emails that wasn't added to the email-bounced remove list and the error reason")
    @JsonProperty(JSON_PROPERTY_ERRORS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<BouncesRemoveListError> getErrors() {
        return errors;
    }

    @JsonProperty(JSON_PROPERTY_ERRORS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setErrors(List<BouncesRemoveListError> errors) {
        this.errors = errors;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        BouncesRemoveListResult bouncesRemoveListResult = (BouncesRemoveListResult) o;
        return Objects.equals(this.errors, bouncesRemoveListResult.errors);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(errors);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class BouncesRemoveListResult {\n");
        sb.append("    errors: ").append(toIndentedString(errors)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/BouncesRemoveListResult.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.BouncesRemoveListError;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * BouncesRemoveListResult
 */
@JsonPropertyOrder({ BouncesRemoveListResult.JSON_PROPERTY_ERRORS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class BouncesRemoveListResult implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ERRORS = "errors";
    private List<BouncesRemoveListError> errors = null;

    public BouncesRemoveListResult() {
    }

    public BouncesRemoveListResult errors(List<BouncesRemoveListError> errors) {

        this.errors = errors;
        return this;
    }

    public BouncesRemoveListResult adderrorsItem(BouncesRemoveListError errorsItem) {
        if (this.errors == null) {
            this.errors = new ArrayList<>();
        }
        this.errors.add(errorsItem);
        return this;
    }

    /**
     * A list of emails that wasn&#39;t added to the email-bounced remove list and the error reason
     *
     * @return errors
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "A list of emails that wasn't added to the email-bounced remove list and the error reason")
    @JsonProperty(JSON_PROPERTY_ERRORS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<BouncesRemoveListError> getErrors() {
        return errors;
    }

    @JsonProperty(JSON_PROPERTY_ERRORS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setErrors(List<BouncesRemoveListError> errors) {
        this.errors = errors;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        BouncesRemoveListResult bouncesRemoveListResult = (BouncesRemoveListResult) o;
        return Objects.equals(this.errors, bouncesRemoveListResult.errors);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(errors);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class BouncesRemoveListResult {\n");
        sb.append("    errors: ").append(toIndentedString(errors)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
